All files enum.js

100% Statements 72/72
100% Branches 2/2
100% Functions 1/1
100% Lines 72/72

Press n or j to go to the next uncovered block, b, p or k for the previous block.

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 731x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x 1x  
/**
* @license Apache-2.0
*
* Copyright (c) 2026 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
 
'use strict';
 
// MAIN //
 
/**
* Returns an object mapping supported loss functions to integer values for purposes of C inter-operation.
*
* ## Notes
*
* -   Downstream consumers of this mapping should **not** rely on specific integer values (e.g., `HINGE == 0`). Instead, the object should be used in an opaque manner.
* -   The main purpose of this function is JavaScript and C inter-operation.
*
* @returns {Object} object mapping supported loss functions to integer values
*
* @example
* var table = enumerated();
* // returns <Object>
*/
function enumerated() {
	// NOTE: the following should match the C `loss functions.h` enumeration!!!!
	return {
		// Corresponds to a soft-margin linear Support Vector Machine (SVM), which can handle non-linearly separable data:
		'hinge': 0,
 
		// Corresponds to Logistic Regression:
		'log': 1,
 
		// Huber loss function variant for classification:
		'modifiedHuber': 2,
 
		// Squared hinge loss function SVM (L2-SVM):
		'squaredHinge': 3,
 
		// Corresponds to the original perceptron by Rosenblatt (1957):
		'perceptron': 4,
 
		// Squared difference of the observed and fitted values:
		'squaredError': 5,
 
		// Squared-error loss for observations with error smaller than epsilon in magnitude, linear loss otherwise:
		'huber': 6,
 
		// Penalty is the absolute value of the error whenever the absolute error exceeds epsilon and zero otherwise:
		'epsilonInsensitive': 7,
 
		// Squared epsilon insensitive loss function:
		'squaredEpsilonInsensitive': 8
	};
}
 
 
// EXPORTS //
 
module.exports = enumerated;